API documentation
=================

The following API documentation was automatically generated from the source
code of `property-manager3` |release|:

.. contents::
   :local:

:mod:`property_manager3`
-----------------------

.. automodule:: property_manager3
   :members:


:mod:`property_manager3.sphinx`
------------------------------

.. automodule:: property_manager3.sphinx
   :members:
